@@ -1,14 +1,20 @@
-import cPickle as pickle
 import os
 import shutil
 import sys
 import warnings
 
 import rope.base.fscommands
-from rope.base import exceptions, taskhandle, prefs, history, pycore, utils
 import rope.base.resourceobserver as resourceobserver
+import rope.base.utils.pycompat as pycompat
+from rope.base import exceptions, taskhandle, prefs, history, pycore, utils
+from rope.base.exceptions import ModuleNotFoundError
 from rope.base.resources import File, Folder, _ResourceMatcher
 
+try:
+    import pickle
+except ImportError:
+    import cPickle as pickle
+
 
 class _Project(object):
 
@@ -17,6 +23,7 @@ class _Project(object):
         self.fscommands = fscommands
         self.prefs = prefs.Prefs()
         self.data_files = _DataFiles(self)
+        self._custom_source_folders = []
 
     def get_resource(self, resource_name):
         """Get a resource in a project.
@@ -41,6 +48,40 @@ class _Project(object):
             raise exceptions.ResourceNotFoundError('Unknown resource '
                                                    + resource_name)
 
+    def get_module(self, name, folder=None):
+        """Returns a `PyObject` if the module was found."""
+        # check if this is a builtin module
+        pymod = self.pycore.builtin_module(name)
+        if pymod is not None:
+            return pymod
+        module = self.find_module(name, folder)
+        if module is None:
+            raise ModuleNotFoundError('Module %s not found' % name)
+        return self.pycore.resource_to_pyobject(module)
+
+    def get_python_path_folders(self):
+        result = []
+        for src in self.prefs.get('python_path', []) + sys.path:
+            try:
+                src_folder = get_no_project().get_resource(src)
+                result.append(src_folder)
+            except exceptions.ResourceNotFoundError:
+                pass
+        return result
+
+    # INFO: It was decided not to cache source folders, since:
+    #  - Does not take much time when the root folder contains
+    #    packages, that is most of the time
+    #  - We need a separate resource observer; `self.observer`
+    #    does not get notified about module and folder creations
+    def get_source_folders(self):
+        """Returns project source folders"""
+        if self.root is None:
+            return []
+        result = list(self._custom_source_folders)
+        result.extend(self.pycore._find_source_folders(self.root))
+        return result
+
     def validate(self, folder):
         """Validate files and folders contained in this folder
 
@@ -71,6 +112,9 @@ class _Project(object):
         """
         self.history.do(changes, task_handle=task_handle)
 
+    def get_pymodule(self, resource, force_errors=False):
+        return self.pycore.resource_to_pyobject(resource, force_errors)
+
     def get_pycore(self):
         return self.pycore
 
@@ -82,12 +126,45 @@ class _Project(object):
         """Get the folder with `path` (it may not exist)"""
         return Folder(self, path)
 
-    def is_ignored(self, resource):
-        return False
-
     def get_prefs(self):
         return self.prefs
 
+    def get_relative_module(self, name, folder, level):
+        module = self.find_relative_module(name, folder, level)
+        if module is None:
+            raise ModuleNotFoundError('Module %s not found' % name)
+        return self.pycore.resource_to_pyobject(module)
+
+    def find_module(self, modname, folder=None):
+        """Returns a resource corresponding to the given module
+
+        returns None if it can not be found
+        """
+        for src in self.get_source_folders():
+            module = _find_module_in_folder(src, modname)
+            if module is not None:
+                return module
+        for src in self.get_python_path_folders():
+            module = _find_module_in_folder(src, modname)
+            if module is not None:
+                return module
+        if folder is not None:
+            module = _find_module_in_folder(folder, modname)
+            if module is not None:
+                return module
+        return None
+
+    def find_relative_module(self, modname, folder, level):
+        for i in range(level - 1):
+            folder = folder.parent
+        if modname == '':
+            return folder
+        else:
+            return _find_module_in_folder(folder, modname)
+
+    def is_ignored(self, resource):
+        return False
+
     def _get_resource_path(self, name):
         pass
 
@@ -144,10 +221,22 @@ class Project(_Project):
         if ropefolder is not None:
             self.prefs['ignored_resources'] = [ropefolder]
         self._init_prefs(prefs)
+        self._init_source_folders()
+
+    @utils.deprecated('Delete once deprecated functions are gone')
+    def _init_source_folders(self):
+        for path in self.prefs.get('source_folders', []):
+            folder = self.get_resource(path)
+            self._custom_source_folders.append(folder)
 
     def get_files(self):
         return self.file_list.get_files()
 
+    def get_python_files(self):
+        """Returns all python files available in the project"""
+        return [resource for resource in self.get_files()
+                if self.pycore.is_python_file(resource)]
+
     def _get_resource_path(self, name):
         return os.path.join(self._address, *name.split('/'))
 
@@ -173,7 +262,7 @@ class Project(_Project):
                                 '__file__': config.real_path})
             if config.exists():
                 config = self.ropefolder.get_child('config.py')
-                execfile(config.real_path, run_globals)
+                pycompat.execfile(config.real_path, run_globals)
             else:
                 exec(self._default_config(), run_globals)
             if 'set_prefs' in run_globals:
@@ -244,6 +333,9 @@ class NoProject(_Project):
     def get_files(self):
         return []
 
+    def get_python_files(self):
+        return []
+
     _no_project = None
 
 
@@ -366,10 +458,34 @@ def _realpath(path):
 
     Is equivalent to ``realpath(abspath(expanduser(path)))``.
 
+    Of the particular notice is the hack dealing with the unfortunate
+    sitaution of running native-Windows python (os.name == 'nt') inside
+    of Cygwin (abspath starts with '/'), which apparently normal
+    os.path.realpath completely messes up.
+
     """
     # there is a bug in cygwin for os.path.abspath() for abs paths
     if sys.platform == 'cygwin':
         if path[1:3] == ':\\':
             return path
+        elif path[1:3] == ':/':
+            path = "/cygdrive/" + path[0] + path[2:]
         return os.path.abspath(os.path.expanduser(path))
     return os.path.realpath(os.path.abspath(os.path.expanduser(path)))
+
+
+def _find_module_in_folder(folder, modname):
+    module = folder
+    packages = modname.split('.')
+    for pkg in packages[:-1]:
+        if module.is_folder() and module.has_child(pkg):
+            module = module.get_child(pkg)
+        else:
+            return None
+    if module.is_folder():
+        if module.has_child(packages[-1]) and \
+           module.get_child(packages[-1]).is_folder():
+            return module.get_child(packages[-1])
+        elif module.has_child(packages[-1] + '.py') and \
+                not module.get_child(packages[-1] + '.py').is_folder():
+            return module.get_child(packages[-1] + '.py')
