@@ -1,13 +1,19 @@
 import os
+import re
 import sys
 
 from rope.base import utils
+from rope.base.utils import pycompat
 
 
 def _stdlib_path():
-    import distutils.sysconfig
-    return distutils.sysconfig.get_python_lib(standard_lib=True,
-                                              plat_specific=True)
+    if pycompat.PY2:
+        from distutils import sysconfig
+        return sysconfig.get_python_lib(standard_lib=True,
+                                        plat_specific=True)
+    elif pycompat.PY3:
+        import inspect
+        return os.path.dirname(inspect.getsourcefile(inspect))
 
 
 @utils.cached(1)
@@ -31,6 +37,15 @@ def python_modules():
     return result
 
 
+def normalize_so_name(name):
+    """
+    Handle different types of python installations
+    """
+    if "cpython" in name:
+        return os.path.splitext(os.path.splitext(name)[0])[0]
+    return os.path.splitext(name)[0]
+
+
 @utils.cached(1)
 def dynload_modules():
     result = set(sys.builtin_module_names)
@@ -40,7 +55,7 @@ def dynload_modules():
             path = os.path.join(dynload_path, name)
             if os.path.isfile(path):
                 if name.endswith('.dll'):
-                    result.add(os.path.splitext(name)[0])
+                    result.add(normalize_so_name(name))
                 if name.endswith('.so'):
-                    result.add(os.path.splitext(name)[0].replace('module', ''))
+                    result.add(normalize_so_name(name))
     return result
