@@ -1,13 +1,16 @@
 import rope.base.codeanalyze
 import rope.base.evaluate
-from rope.base import worder, exceptions, utils
+from rope.base import exceptions
+from rope.base import libutils
+from rope.base import utils
+from rope.base import worder
 from rope.base.codeanalyze import ArrayLinesAdapter, LogicalLineFinder
 
 
 class FixSyntax(object):
 
-    def __init__(self, pycore, code, resource, maxfixes=1):
-        self.pycore = pycore
+    def __init__(self, project, code, resource, maxfixes=1):
+        self.project = project
         self.code = code
         self.resource = resource
         self.maxfixes = maxfixes
@@ -22,11 +25,12 @@ class FixSyntax(object):
             try:
                 if tries == 0 and self.resource is not None and \
                    self.resource.read() == code:
-                    return self.pycore.resource_to_pyobject(self.resource,
-                                                            force_errors=True)
-                return self.pycore.get_string_module(
-                    code, resource=self.resource, force_errors=True)
-            except exceptions.ModuleSyntaxError, e:
+                    return self.project.get_pymodule(self.resource,
+                                                     force_errors=True)
+                return libutils.get_string_module(
+                    self.project, code, resource=self.resource,
+                    force_errors=True)
+            except exceptions.ModuleSyntaxError as e:
                 if msg is None:
                     msg = '%s:%s %s' % (e.filename, e.lineno, e.message_)
                 if tries < self.maxfixes:
@@ -34,8 +38,9 @@ class FixSyntax(object):
                     self.commenter.comment(e.lineno)
                     code = '\n'.join(self.commenter.lines)
                 else:
-                    raise exceptions.ModuleSyntaxError(e.filename,
-                                                       e.lineno, msg)
+                    raise exceptions.ModuleSyntaxError(
+                        e.filename, e.lineno,
+                        'Failed to fix error: {0}'.format(msg))
 
     @property
     @utils.saveit
@@ -71,7 +76,7 @@ class _Commenter(object):
         self.code = code
         self.lines = self.code.split('\n')
         self.lines.append('\n')
-        self.origs = range(len(self.lines) + 1)
+        self.origs = list(range(len(self.lines) + 1))
         self.diffs = [0] * (len(self.lines) + 1)
 
     def comment(self, lineno):
