@@ -1,8 +1,12 @@
 import sys
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 import ropetest.projecttest
 import ropetest.codeanalyzetest
+import ropetest.type_hinting_test
 import ropetest.pycoretest
 import ropetest.pyscopestest
 import ropetest.objectinfertest
@@ -13,11 +17,15 @@ import ropetest.builtinstest
 import ropetest.historytest
 import ropetest.simplifytest
 
+import ropetest.contrib
+import ropetest.refactor
+
 
 def suite():
     result = unittest.TestSuite()
     result.addTests(ropetest.projecttest.suite())
     result.addTests(ropetest.codeanalyzetest.suite())
+    result.addTests(ropetest.type_hinting_test.suite())
     result.addTests(ropetest.pycoretest.suite())
     result.addTests(ropetest.pyscopestest.suite())
     result.addTests(ropetest.objectinfertest.suite())
@@ -27,6 +35,10 @@ def suite():
     result.addTests(ropetest.builtinstest.suite())
     result.addTests(ropetest.historytest.suite())
     result.addTests(ropetest.simplifytest.suite())
+
+    result.addTests(ropetest.refactor.suite())
+    result.addTests(ropetest.contrib.suite())
+
     return result
 
 
