@@ -1,4 +1,8 @@
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
+
 
 from ropetest import testutils
 from rope.contrib.fixmodnames import FixModuleNames
