@@ -1,4 +1,7 @@
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 import rope.base.taskhandle
 import rope.refactor.introduce_parameter
@@ -46,7 +49,8 @@ class MethodObjectTest(unittest.TestCase):
         self.mod.write(code)
         replacer = MethodObject(self.project, self.mod, code.index('func'))
         self.assertEquals(
-            'class _New(object):\n\n    def __call__(self):\n        return 1\n',
+            'class _New(object):\n\n    def __call__(self):'
+            '\n        return 1\n',
             replacer.get_new_class('_New'))
 
     def test_multi_line_header(self):
@@ -54,7 +58,8 @@ class MethodObjectTest(unittest.TestCase):
         self.mod.write(code)
         replacer = MethodObject(self.project, self.mod, code.index('func'))
         self.assertEquals(
-            'class _New(object):\n\n    def __call__(self):\n        return 1\n',
+            'class _New(object):\n\n    def __call__(self):'
+            '\n        return 1\n',
             replacer.get_new_class('_New'))
 
     def test_a_single_parameter(self):
@@ -99,15 +104,16 @@ class MethodObjectTest(unittest.TestCase):
                    '        self.args = args\n' \
                    '        self.kwds = kwds\n\n' \
                    '    def __call__(self):\n' \
-                   '        result = self.arg + self.args[0] + self.kwds[self.arg]\n' \
+                   '        result = self.arg + ' \
+                   'self.args[0] + self.kwds[self.arg]\n' \
                    '        return result\n'
         self.assertEquals(expected, replacer.get_new_class('_New'))
 
-    @testutils.assert_raises(RefactoringError)
     def test_performing_on_not_a_function(self):
         code = 'my_var = 10\n'
         self.mod.write(code)
-        replacer = MethodObject(self.project, self.mod, code.index('my_var'))
+        with self.assertRaises(RefactoringError):
+            MethodObject(self.project, self.mod, code.index('my_var'))
 
     def test_changing_the_module(self):
         code = 'def func():\n    return 1\n'
@@ -209,7 +215,8 @@ class IntroduceFactoryTest(unittest.TestCase):
         mod2 = testutils.create_module(self.project, 'mod2')
         mod1.write('class AClass(object):\n    an_attr = 10\n')
         mod2.write('import mod1\na_var = mod1.AClass()\n')
-        self._introduce_factory(mod1, mod1.read().index('AClass') + 1, 'create')
+        self._introduce_factory(mod1, mod1.read().index('AClass') + 1,
+                                'create')
         expected1 = 'class AClass(object):\n' \
                     '    an_attr = 10\n\n' \
                     '    @staticmethod\n' \
@@ -220,11 +227,12 @@ class IntroduceFactoryTest(unittest.TestCase):
         self.assertEquals(expected1, mod1.read())
         self.assertEquals(expected2, mod2.read())
 
-    @testutils.assert_raises(RefactoringError)
     def test_raising_exception_for_non_classes(self):
         mod = testutils.create_module(self.project, 'mod')
         mod.write('def a_func():\n    pass\n')
-        self._introduce_factory(mod, mod.read().index('a_func') + 1, 'create')
+        with self.assertRaises(RefactoringError):
+            self._introduce_factory(mod, mod.read().index('a_func') + 1,
+                                    'create')
 
     def test_undoing_introduce_factory(self):
         mod1 = testutils.create_module(self.project, 'mod1')
@@ -233,7 +241,8 @@ class IntroduceFactoryTest(unittest.TestCase):
         mod1.write(code1)
         code2 = 'from mod1 import AClass\na_var = AClass()\n'
         mod2.write(code2)
-        self._introduce_factory(mod1, mod1.read().index('AClass') + 1, 'create')
+        self._introduce_factory(mod1, mod1.read().index('AClass') + 1,
+                                'create')
         self.project.history.undo()
         self.assertEquals(code1, mod1.read())
         self.assertEquals(code2, mod2.read())
@@ -243,7 +252,8 @@ class IntroduceFactoryTest(unittest.TestCase):
         mod2 = testutils.create_module(self.project, 'mod2')
         mod1.write('class AClass(object):\n    an_attr = 10\n')
         mod2.write('import mod1\na_var = mod1.AClass()\n')
-        self._introduce_factory(mod2, mod2.read().index('AClass') + 1, 'create')
+        self._introduce_factory(mod2, mod2.read().index('AClass') + 1,
+                                'create')
         expected1 = 'class AClass(object):\n' \
                     '    an_attr = 10\n\n' \
                     '    @staticmethod\n' \
@@ -264,7 +274,8 @@ class IntroduceFactoryTest(unittest.TestCase):
         expected = 'def create_var():\n'\
                    '    class AClass(object):\n'\
                    '        an_attr = 10\n\n'\
-                   '        @staticmethod\n        def create(*args, **kwds):\n'\
+                   '        @staticmethod\n        ' \
+                   'def create(*args, **kwds):\n'\
                    '            return AClass(*args, **kwds)\n'\
                    '    return AClass.create()\n'
         self._introduce_factory(mod, mod.read().index('AClass') + 1, 'create')
@@ -279,7 +290,7 @@ class IntroduceFactoryTest(unittest.TestCase):
                    'def create(*args, **kwds):\n' \
                    '    return AClass(*args, **kwds)\n'
         self._introduce_factory(mod, mod.read().index('AClass') + 1,
-                                        'create', global_factory=True)
+                                'create', global_factory=True)
         self.assertEquals(expected, mod.read())
 
     def test_get_name_for_factories(self):
@@ -290,7 +301,6 @@ class IntroduceFactoryTest(unittest.TestCase):
                                    mod.read().index('C') + 1)
         self.assertEquals('C', factory.get_name())
 
-    @testutils.assert_raises(RefactoringError)
     def test_raising_exception_for_global_factory_for_nested_classes(self):
         code = 'def create_var():\n'\
                '    class AClass(object):\n'\
@@ -298,8 +308,9 @@ class IntroduceFactoryTest(unittest.TestCase):
                '    return AClass()\n'
         mod = testutils.create_module(self.project, 'mod')
         mod.write(code)
-        self._introduce_factory(mod, mod.read().index('AClass') + 1,
-                                           'create', global_factory=True)
+        with self.assertRaises(RefactoringError):
+            self._introduce_factory(mod, mod.read().index('AClass') + 1,
+                                    'create', global_factory=True)
 
     def test_changing_occurances_in_the_main_module_for_global_factories(self):
         code = 'class AClass(object):\n' \
@@ -312,7 +323,7 @@ class IntroduceFactoryTest(unittest.TestCase):
                    '    return AClass(*args, **kwds)\n'\
                    'a_var = create()'
         self._introduce_factory(mod, mod.read().index('AClass') + 1,
-                                           'create', global_factory=True)
+                                'create', global_factory=True)
         self.assertEquals(expected, mod.read())
 
     def test_changing_occurances_in_other_modules_for_global_factories(self):
@@ -321,7 +332,7 @@ class IntroduceFactoryTest(unittest.TestCase):
         mod1.write('class AClass(object):\n    an_attr = 10\n')
         mod2.write('import mod1\na_var = mod1.AClass()\n')
         self._introduce_factory(mod1, mod1.read().index('AClass') + 1,
-                                           'create', global_factory=True)
+                                'create', global_factory=True)
         expected1 = 'class AClass(object):\n' \
                     '    an_attr = 10\n\n' \
                     'def create(*args, **kwds):\n' \
@@ -331,13 +342,13 @@ class IntroduceFactoryTest(unittest.TestCase):
         self.assertEquals(expected1, mod1.read())
         self.assertEquals(expected2, mod2.read())
 
-    def test_importing_if_necessary_in_other_modules_for_global_factories(self):
+    def test_import_if_necessary_in_other_mods_for_global_factories(self):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod2 = testutils.create_module(self.project, 'mod2')
         mod1.write('class AClass(object):\n    an_attr = 10\n')
         mod2.write('from mod1 import AClass\npair = AClass(), AClass\n')
         self._introduce_factory(mod1, mod1.read().index('AClass') + 1,
-                                           'create', global_factory=True)
+                                'create', global_factory=True)
         expected1 = 'class AClass(object):\n' \
                     '    an_attr = 10\n\n' \
                     'def create(*args, **kwds):\n' \
@@ -348,7 +359,8 @@ class IntroduceFactoryTest(unittest.TestCase):
         self.assertEquals(expected2, mod2.read())
 
     def test_changing_occurances_for_renamed_classes(self):
-        code = 'class AClass(object):\n    an_attr = 10\na_class = AClass\na_var = a_class()'
+        code = 'class AClass(object):\n    an_attr = 10' \
+            '\na_class = AClass\na_var = a_class()'
         mod = testutils.create_module(self.project, 'mod')
         mod.write(code)
         expected = 'class AClass(object):\n' \
@@ -361,7 +373,7 @@ class IntroduceFactoryTest(unittest.TestCase):
         self._introduce_factory(mod, mod.read().index('a_class') + 1, 'create')
         self.assertEquals(expected, mod.read())
 
-    def test_changing_occurrences_in_the_same_module_with_conflicting_ranges(self):
+    def test_changing_occurrs_in_the_same_module_with_conflict_ranges(self):
         mod = testutils.create_module(self.project, 'mod')
         code = 'class C(object):\n' \
                '    def create(self):\n' \
@@ -453,7 +465,7 @@ class EncapsulateFieldTest(unittest.TestCase):
 
     def _encapsulate(self, resource, offset, **args):
         changes = EncapsulateField(self.project, resource, offset).\
-                  get_changes(**args)
+            get_changes(**args)
         self.project.do(changes)
 
     def test_adding_getters_and_setters(self):
@@ -519,21 +531,20 @@ class EncapsulateFieldTest(unittest.TestCase):
 
     def test_changing_main_module_occurances(self):
         code = self.a_class + \
-               'a_var = A()\n' \
-               'a_var.attr = a_var.attr * 2\n'
+            'a_var = A()\n' \
+            'a_var.attr = a_var.attr * 2\n'
         self.mod1.write(code)
         self._encapsulate(self.mod1, self.mod1.read().index('attr') + 1)
         expected = self.encapsulated + \
-                   'a_var = A()\n' \
-                   'a_var.set_attr(a_var.get_attr() * 2)\n'
+            'a_var = A()\n' \
+            'a_var.set_attr(a_var.get_attr() * 2)\n'
         self.assertEquals(expected, self.mod1.read())
 
-    @testutils.assert_raises(RefactoringError)
     def test_raising_exception_when_performed_on_non_attributes(self):
         self.mod1.write('attr = 10')
-        self._encapsulate(self.mod1, self.mod1.read().index('attr') + 1)
+        with self.assertRaises(RefactoringError):
+            self._encapsulate(self.mod1, self.mod1.read().index('attr') + 1)
 
-    @testutils.assert_raises(RefactoringError)
     def test_raising_exception_on_tuple_assignments(self):
         self.mod.write(self.a_class)
         code = 'import mod\n' \
@@ -541,9 +552,9 @@ class EncapsulateFieldTest(unittest.TestCase):
                'a_var.attr = 1\n' \
                'a_var.attr, b = 1, 2\n'
         self.mod1.write(code)
-        self._encapsulate(self.mod1, self.mod1.read().index('attr') + 1)
+        with self.assertRaises(RefactoringError):
+            self._encapsulate(self.mod1, self.mod1.read().index('attr') + 1)
 
-    @testutils.assert_raises(RefactoringError)
     def test_raising_exception_on_tuple_assignments2(self):
         self.mod.write(self.a_class)
         code = 'import mod\n' \
@@ -551,7 +562,8 @@ class EncapsulateFieldTest(unittest.TestCase):
                'a_var.attr = 1\n' \
                'b, a_var.attr = 1, 2\n'
         self.mod1.write(code)
-        self._encapsulate(self.mod1, self.mod1.read().index('attr') + 1)
+        with self.assertRaises(RefactoringError):
+            self._encapsulate(self.mod1, self.mod1.read().index('attr') + 1)
 
     def test_tuple_assignments_and_function_calls(self):
         code = 'import mod\n' \
@@ -607,14 +619,14 @@ class EncapsulateFieldTest(unittest.TestCase):
 
     def test_changing_occurrences_inside_the_class(self):
         new_class = self.a_class + '\n' \
-                    '    def a_func(self):\n' \
-                    '        self.attr = 1\n'
+            '    def a_func(self):\n' \
+            '        self.attr = 1\n'
         self.mod.write(new_class)
         self._encapsulate(self.mod, self.mod.read().index('attr') + 1)
         expected = self.a_class + '\n' \
-                   '    def a_func(self):\n' \
-                   '        self.set_attr(1)\n' + \
-                   self.added_methods
+            '    def a_func(self):\n' \
+            '        self.set_attr(1)\n' + \
+            self.added_methods
         self.assertEquals(expected, self.mod.read())
 
     def test_getter_and_setter_parameters(self):
@@ -622,7 +634,7 @@ class EncapsulateFieldTest(unittest.TestCase):
         self._encapsulate(self.mod, self.mod.read().index('attr') + 1,
                           getter='getAttr', setter='setAttr')
         new_methods = self.added_methods.replace('get_attr', 'getAttr').\
-                      replace('set_attr', 'setAttr')
+            replace('set_attr', 'setAttr')
         expected = self.a_class + new_methods
         self.assertEquals(expected, self.mod.read())
 
@@ -666,33 +678,33 @@ class LocalToFieldTest(unittest.TestCase):
                    '        self.var = 10\n'
         self.assertEquals(expected, self.mod.read())
 
-    @testutils.assert_raises(RefactoringError)
     def test_raising_exception_when_performed_on_a_global_var(self):
         self.mod.write('var = 10\n')
-        self._perform_convert_local_variable_to_field(
-            self.mod, self.mod.read().index('var') + 1)
+        with self.assertRaises(RefactoringError):
+            self._perform_convert_local_variable_to_field(
+                self.mod, self.mod.read().index('var') + 1)
 
-    @testutils.assert_raises(RefactoringError)
     def test_raising_exception_when_performed_on_field(self):
         code = 'class A(object):\n' \
                '    def a_func(self):\n' \
                '        self.var = 10\n'
         self.mod.write(code)
-        self._perform_convert_local_variable_to_field(
-            self.mod, self.mod.read().index('var') + 1)
+        with self.assertRaises(RefactoringError):
+            self._perform_convert_local_variable_to_field(
+                self.mod, self.mod.read().index('var') + 1)
 
-    @testutils.assert_raises(RefactoringError)
     def test_raising_exception_when_performed_on_a_parameter(self):
         code = 'class A(object):\n' \
                '    def a_func(self, var):\n' \
                '        a = var\n'
         self.mod.write(code)
-        self._perform_convert_local_variable_to_field(
-            self.mod, self.mod.read().index('var') + 1)
+        with self.assertRaises(RefactoringError):
+            self._perform_convert_local_variable_to_field(
+                self.mod, self.mod.read().index('var') + 1)
 
     # NOTE: This situation happens alot and is normally not an error
     #@testutils.assert_raises(RefactoringError)
-    def test_not_raising_exception_when_there_is_a_field_with_the_same_name(self):
+    def test_not_rais_exception_when_there_is_a_field_with_the_same_name(self):
         code = 'class A(object):\n' \
                '    def __init__(self):\n' \
                '        self.var = 1\n' \
@@ -707,7 +719,7 @@ class LocalToFieldTest(unittest.TestCase):
                '        var = 10\n'
         self.mod.write(code)
         self._perform_convert_local_variable_to_field(self.mod,
-                                                         code.index('var') + 1)
+                                                      code.index('var') + 1)
         expected = 'class A(object):\n' \
                    '    def a_func(myself):\n' \
                    '        myself.var = 10\n'
@@ -754,19 +766,19 @@ class IntroduceParameterTest(unittest.TestCase):
                    '    b = p1\n'
         self.assertEquals(expected, self.mod.read())
 
-    @testutils.assert_raises(RefactoringError)
     def test_unknown_variables(self):
         self.mod.write('def f():\n    b = var + c\n')
         offset = self.mod.read().rindex('var')
-        self._introduce_parameter(offset, 'p1')
-        self.assertEquals('def f(p1=var):\n    b = p1 + c\n',
-                          self.mod.read())
+        with self.assertRaises(RefactoringError):
+            self._introduce_parameter(offset, 'p1')
+            self.assertEquals('def f(p1=var):\n    b = p1 + c\n',
+                              self.mod.read())
 
-    @testutils.assert_raises(RefactoringError)
     def test_failing_when_not_inside(self):
         self.mod.write('var = 10\nb = var\n')
         offset = self.mod.read().rindex('var')
-        self._introduce_parameter(offset, 'p1')
+        with self.assertRaises(RefactoringError):
+            self._introduce_parameter(offset, 'p1')
 
     def test_attribute_accesses(self):
         code = 'class C(object):\n' \
@@ -806,6 +818,7 @@ class _MockTaskObserver(object):
     def __call__(self):
         self.called += 1
 
+
 class TaskHandleTest(unittest.TestCase):
 
     def test_trivial_case(self):
@@ -828,19 +841,19 @@ class TaskHandleTest(unittest.TestCase):
         jobs.started_job('job1')
         jobs.finished_job()
 
-    @testutils.assert_raises(InterruptedTaskError)
     def test_test_checking_status(self):
         handle = rope.base.taskhandle.TaskHandle()
         jobs = handle.create_jobset()
         handle.stop()
-        jobs.check_status()
+        with self.assertRaises(InterruptedTaskError):
+            jobs.check_status()
 
-    @testutils.assert_raises(InterruptedTaskError)
     def test_test_checking_status_when_starting(self):
         handle = rope.base.taskhandle.TaskHandle()
         jobs = handle.create_jobset()
         handle.stop()
-        jobs.started_job('job1')
+        with self.assertRaises(InterruptedTaskError):
+            jobs.started_job('job1')
 
     def test_calling_the_observer_after_stopping(self):
         handle = rope.base.taskhandle.TaskHandle()
@@ -853,7 +866,7 @@ class TaskHandleTest(unittest.TestCase):
         handle = rope.base.taskhandle.TaskHandle()
         observer = _MockTaskObserver()
         handle.add_observer(observer)
-        jobs = handle.create_jobset()
+        jobs = handle.create_jobset()  # noqa
         self.assertEquals(1, observer.called)
 
     def test_calling_the_observer_when_starting_and_finishing_jobs(self):
