@@ -1,4 +1,7 @@
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 from rope.refactor.importutils import ImportTools, importinfo, add_import
 from ropetest import testutils
@@ -275,6 +278,18 @@ class ImportUtilsTest(unittest.TestCase):
         self.assertEquals('import pkg1.mod1\n',
                           module_with_imports.get_changed_source())
 
+    def test_adding_imports_no_pull_to_top(self):
+        self.mod.write('import pkg2.mod3\nclass A(object):\n    pass\n\n'
+                       'import pkg2.mod2\n')
+        pymod = self.project.get_module('mod')
+        self.project.prefs['pull_imports_to_top'] = False
+        module_with_imports = self.import_tools.module_imports(pymod)
+        new_import = self.import_tools.get_import(self.mod1)
+        module_with_imports.add_import(new_import)
+        self.assertEquals('import pkg2.mod3\nclass A(object):\n    pass\n\n'
+                          'import pkg2.mod2\nimport pkg1.mod1\n',
+                          module_with_imports.get_changed_source())
+
     def test_adding_from_imports(self):
         self.mod1.write('def a_func():\n    pass\n'
                         'def another_func():\n    pass\n')
@@ -630,6 +645,33 @@ class ImportUtilsTest(unittest.TestCase):
                           self.import_tools.organize_imports(pymod,
                                                              unused=False))
 
+    def test_splitting_imports_no_pull_to_top(self):
+        self.mod.write('from pkg2 import mod3, mod4\n'
+                       'from pkg1 import mod2\nfrom pkg1 import mod1\n')
+        pymod = self.project.get_pymodule(self.mod)
+        self.project.prefs['split_imports'] = True
+        self.project.prefs['pull_imports_to_top'] = False
+        self.assertEquals('from pkg1 import mod2\nfrom pkg1 import mod1\n'
+                          'from pkg2 import mod3\nfrom pkg2 import mod4\n',
+                          self.import_tools.organize_imports(pymod,
+                                                             sort=False,
+                                                             unused=False))
+
+    def test_splitting_imports_with_filter(self):
+        self.mod.write('from pkg1 import mod1, mod2\n'
+                       'from pkg2 import mod3, mod4\n')
+        pymod = self.project.get_pymodule(self.mod)
+        self.project.prefs['split_imports'] = True
+
+        def import_filter(stmt):
+          return stmt.import_info.module_name == 'pkg1'
+
+        self.assertEquals(
+            'from pkg1 import mod1\nfrom pkg1 import mod2\n'
+            'from pkg2 import mod3, mod4\n',
+            self.import_tools.organize_imports(pymod, unused=False,
+                                               import_filter=import_filter))
+
     def test_splitting_duplicate_imports(self):
         self.mod.write('from pkg2 import mod1\nfrom pkg2 import mod1, mod2\n')
         pymod = self.project.get_pymodule(self.mod)
@@ -848,6 +890,18 @@ class ImportUtilsTest(unittest.TestCase):
         self.assertEquals('import mod\n\n\ndef f():\n    print(mod)\n',
                           self.import_tools.sort_imports(pymod))
 
+    # Sort pulls imports to the top anyway
+    def test_sorting_imports_no_pull_to_top(self):
+        code = ('import pkg2\ndef f():\n    print(mod, pkg1, pkg2)\n'
+                'import pkg1\nimport mod\n')
+        self.mod.write(code)
+        pymod = self.project.get_module('mod')
+        self.project.prefs['pull_imports_to_top'] = False
+        self.assertEquals(
+            'import mod\nimport pkg1\nimport pkg2\n\n\n'
+            'def f():\n    print(mod, pkg1, pkg2)\n',
+            self.import_tools.sort_imports(pymod))
+
     def test_sorting_imports_moving_to_top_and_module_docs(self):
         self.mod.write('"""\ndocs\n"""\ndef f():'
                        '\n    print(mod)\nimport mod\n')
@@ -856,6 +910,26 @@ class ImportUtilsTest(unittest.TestCase):
             '"""\ndocs\n"""\nimport mod\n\n\ndef f():\n    print(mod)\n',
             self.import_tools.sort_imports(pymod))
 
+    def test_sorting_imports_moving_to_top_and_module_docs2(self):
+        self.mod.write('"""\ndocs\n"""\n\n\nimport bbb\nimport aaa\n'
+                       'def f():\n    print(mod)\nimport mod\n')
+        pymod = self.project.get_module('mod')
+        self.assertEquals(
+            '"""\ndocs\n"""\n\n\nimport aaa\nimport bbb\n\n'
+            'import mod\n\n\ndef f():\n    print(mod)\n',
+            self.import_tools.sort_imports(pymod))
+
+    def test_get_changed_source_preserves_blank_lines(self):
+        self.mod.write(
+            '__author__ = "author"\n\nimport aaa\n\nimport bbb\n\n'
+            'def f():\n    print(mod)\n')
+        pymod = self.project.get_module('mod')
+        module_with_imports = self.import_tools.module_imports(pymod)
+        self.assertEquals(
+            'import aaa\n\nimport bbb\n\n__author__ = "author"\n\n'
+            'def f():\n    print(mod)\n',
+            module_with_imports.get_changed_source())
+
     def test_sorting_future_imports(self):
         self.mod.write('import os\nfrom __future__ import devision\n')
         pymod = self.project.get_module('mod')
