@@ -13,7 +13,6 @@ class MoveRefactoringTest(unittest.TestCase):
     def setUp(self):
         super(MoveRefactoringTest, self).setUp()
         self.project = testutils.sample_project()
-        self.pycore = self.project.pycore
         self.mod1 = testutils.create_module(self.project, 'mod1')
         self.mod2 = testutils.create_module(self.project, 'mod2')
         self.mod3 = testutils.create_module(self.project, 'mod3')
@@ -30,6 +29,35 @@ class MoveRefactoringTest(unittest.TestCase):
             get_changes(dest_resource)
         self.project.do(changes)
 
+    def test_move_constant(self):
+        self.mod1.write('foo = 123\n')
+        self._move(self.mod1, self.mod1.read().index('foo') + 1,
+                   self.mod2)
+        self.assertEquals('', self.mod1.read())
+        self.assertEquals('foo = 123\n', self.mod2.read())
+
+    def test_move_constant_2(self):
+        self.mod1.write('bar = 321\nfoo = 123\n')
+        self._move(self.mod1, self.mod1.read().index('foo') + 1,
+                   self.mod2)
+        self.assertEquals('bar = 321\n', self.mod1.read())
+        self.assertEquals('foo = 123\n', self.mod2.read())
+
+    def test_move_constant_multiline(self):
+        self.mod1.write('foo = (\n    123\n)\n')
+        self._move(self.mod1, self.mod1.read().index('foo') + 1,
+                   self.mod2)
+        self.assertEquals('', self.mod1.read())
+        self.assertEquals('foo = (\n    123\n)\n', self.mod2.read())
+
+    def test_move_constant_multiple_statements(self):
+        self.mod1.write('foo = 123\nfoo += 3\nfoo = 4\n')
+        self._move(self.mod1, self.mod1.read().index('foo') + 1,
+                   self.mod2)
+        self.assertEquals('import mod2\nmod2.foo += 3\nmod2.foo = 4\n',
+                          self.mod1.read())
+        self.assertEquals('foo = 123\n', self.mod2.read())
+
     def test_simple_moving(self):
         self.mod1.write('class AClass(object):\n    pass\n')
         self._move(self.mod1, self.mod1.read().index('AClass') + 1,
@@ -38,14 +66,79 @@ class MoveRefactoringTest(unittest.TestCase):
         self.assertEquals('class AClass(object):\n    pass\n',
                           self.mod2.read())
 
-    def test_changing_other_modules_adding_normal_imports(self):
+    def test_moving_with_comment_prefix(self):
+        self.mod1.write('a = 1\n# 1\n# 2\nclass AClass(object):\n    pass\n')
+        self._move(self.mod1, self.mod1.read().index('AClass') + 1,
+                   self.mod2)
+        self.assertEquals('a = 1\n', self.mod1.read())
+        self.assertEquals('# 1\n# 2\nclass AClass(object):\n    pass\n',
+                          self.mod2.read())
+
+    def test_moving_with_comment_prefix_imports(self):
+        self.mod1.write('import foo\na = 1\n# 1\n# 2\n'
+                        'class AClass(foo.FooClass):\n    pass\n')
+        self._move(self.mod1, self.mod1.read().index('AClass') + 1,
+                   self.mod2)
+        self.assertEquals('a = 1\n', self.mod1.read())
+        self.assertEquals('import foo\n\n\n# 1\n# 2\n'
+                          'class AClass(foo.FooClass):\n    pass\n',
+                          self.mod2.read())
+
+    def test_changing_other_modules_replacing_normal_imports(self):
         self.mod1.write('class AClass(object):\n    pass\n')
         self.mod3.write('import mod1\na_var = mod1.AClass()\n')
         self._move(self.mod1, self.mod1.read().index('AClass') + 1,
                    self.mod2)
-        self.assertEquals('import mod1\nimport mod2\na_var = mod2.AClass()\n',
+        self.assertEquals('import mod2\na_var = mod2.AClass()\n',
                           self.mod3.read())
 
+    def test_changing_other_modules_adding_normal_imports(self):
+        self.mod1.write('class AClass(object):\n    pass\n'
+                        'def a_function():\n    pass\n')
+        self.mod3.write('import mod1\na_var = mod1.AClass()\n'
+                        'mod1.a_function()')
+        self._move(self.mod1, self.mod1.read().index('AClass') + 1,
+                   self.mod2)
+        self.assertEquals('import mod1\nimport mod2\na_var = mod2.AClass()\n' +
+                          'mod1.a_function()', self.mod3.read())
+
+    def test_adding_imports_prefer_from_module(self):
+        self.project.prefs['prefer_module_from_imports'] = True
+        self.mod1.write('class AClass(object):\n    pass\n'
+                        'def a_function():\n    pass\n')
+        self.mod3.write('import mod1\na_var = mod1.AClass()\n'
+                        'mod1.a_function()')
+        # Move to mod4 which is in a different package
+        self._move(self.mod1, self.mod1.read().index('AClass') + 1,
+                   self.mod4)
+        self.assertEquals('import mod1\nfrom pkg import mod4\n'
+                          'a_var = mod4.AClass()\nmod1.a_function()',
+                          self.mod3.read())
+
+    def test_adding_imports_noprefer_from_module(self):
+        self.project.prefs['prefer_module_from_imports'] = False
+        self.mod1.write('class AClass(object):\n    pass\n'
+                        'def a_function():\n    pass\n')
+        self.mod3.write('import mod1\na_var = mod1.AClass()\n'
+                        'mod1.a_function()')
+        # Move to mod4 which is in a different package
+        self._move(self.mod1, self.mod1.read().index('AClass') + 1,
+                   self.mod4)
+        self.assertEquals('import mod1\nimport pkg.mod4\n'
+                          'a_var = pkg.mod4.AClass()\nmod1.a_function()',
+                          self.mod3.read())
+
+    def test_adding_imports_prefer_from_module_top_level_module(self):
+        self.project.prefs['prefer_module_from_imports'] = True
+        self.mod1.write('class AClass(object):\n    pass\n'
+                        'def a_function():\n    pass\n')
+        self.mod3.write('import mod1\na_var = mod1.AClass()\n'
+                        'mod1.a_function()')
+        self._move(self.mod1, self.mod1.read().index('AClass') + 1,
+                   self.mod2)
+        self.assertEquals('import mod1\nimport mod2\na_var = mod2.AClass()\n' +
+                          'mod1.a_function()', self.mod3.read())
+
     def test_changing_other_modules_removing_from_imports(self):
         self.mod1.write('class AClass(object):\n    pass\n')
         self.mod3.write('from mod1 import AClass\na_var = AClass()\n')
@@ -83,6 +176,13 @@ class MoveRefactoringTest(unittest.TestCase):
             self._move(self.mod1, self.mod1.read().index('AClass') + 1,
                        self.mod2)
 
+    def test_raising_an_exception_for_moving_non_global_variable(self):
+        code = 'class TestClass:\n    CONSTANT = 5\n'
+        self.mod1.write(code)
+        with self.assertRaises(exceptions.RefactoringError):
+            mover = move.create_move(self.project, self.mod1,
+                                     code.index('CONSTANT') + 1)
+
     def test_raising_exception_for_mov_glob_elemnts_to_the_same_module(self):
         self.mod1.write('def a_func():\n    pass\n')
         with self.assertRaises(exceptions.RefactoringError):
@@ -134,6 +234,7 @@ class MoveRefactoringTest(unittest.TestCase):
                    'def a_func():\n' \
                    '    print(pkg.mod5)\n'
         self.assertEquals(expected, self.mod1.read())
+        self.assertEquals('', self.mod4.read())
 
     def test_moving_modules(self):
         code = 'import mod1\nprint(mod1)'
@@ -142,7 +243,7 @@ class MoveRefactoringTest(unittest.TestCase):
         expected = 'import pkg.mod1\nprint(pkg.mod1)'
         self.assertEquals(expected, self.mod2.read())
         self.assertTrue(not self.mod1.exists() and
-                        self.pycore.find_module('pkg.mod1') is not None)
+                        self.project.find_module('pkg.mod1') is not None)
 
     def test_moving_modules_and_removing_out_of_date_imports(self):
         code = 'import pkg.mod4\nprint(pkg.mod4)'
@@ -150,7 +251,7 @@ class MoveRefactoringTest(unittest.TestCase):
         self._move(self.mod2, code.index('mod4') + 1, self.project.root)
         expected = 'import mod4\nprint(mod4)'
         self.assertEquals(expected, self.mod2.read())
-        self.assertTrue(self.pycore.find_module('mod4') is not None)
+        self.assertTrue(self.project.find_module('mod4') is not None)
 
     def test_moving_modules_and_removing_out_of_date_froms(self):
         code = 'from pkg import mod4\nprint(mod4)'
@@ -171,19 +272,28 @@ class MoveRefactoringTest(unittest.TestCase):
         code = 'import pkg.mod4\nprint(pkg.mod4)'
         self.mod2.write(code)
         self._move(self.mod2, code.index('mod4') + 1, self.project.root)
-        moved = self.pycore.find_module('mod4')
+        moved = self.project.find_module('mod4')
         expected = 'import pkg.mod5\nprint(pkg.mod5)\n'
         self.assertEquals(expected, moved.read())
 
+    def test_moving_module_kwarg_same_name_as_old(self):
+        self.mod1.write('def foo(mod1=0):\n    pass')
+        code = 'import mod1\nmod1.foo(mod1=1)'
+        self.mod2.write(code)
+        self._move(self.mod1, None, self.pkg)
+        moved = self.project.find_module('mod2')
+        expected = 'import pkg.mod1\npkg.mod1.foo(mod1=1)'
+        self.assertEquals(expected, moved.read())
+
     def test_moving_packages(self):
         pkg2 = testutils.create_package(self.project, 'pkg2')
         code = 'import pkg.mod4\nprint(pkg.mod4)'
         self.mod1.write(code)
         self._move(self.mod1, code.index('pkg') + 1, pkg2)
         self.assertFalse(self.pkg.exists())
-        self.assertTrue(self.pycore.find_module('pkg2.pkg.mod4') is not None)
-        self.assertTrue(self.pycore.find_module('pkg2.pkg.mod4') is not None)
-        self.assertTrue(self.pycore.find_module('pkg2.pkg.mod5') is not None)
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod4') is not None)
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod4') is not None)
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod5') is not None)
         expected = 'import pkg2.pkg.mod4\nprint(pkg2.pkg.mod4)'
         self.assertEquals(expected, self.mod1.read())
 
@@ -191,10 +301,174 @@ class MoveRefactoringTest(unittest.TestCase):
         self.mod1.write('import mod1\nprint(mod1)\n')
         self.mod2.write('import mod1\n')
         self._move(self.mod2, self.mod2.read().index('mod1') + 1, self.pkg)
-        moved = self.pycore.find_module('pkg.mod1')
+        moved = self.project.find_module('pkg.mod1')
         self.assertEquals('import pkg.mod1\nprint(pkg.mod1)\n', moved.read())
 
-    def test_moving_funtions_to_imported_module(self):
+    def test_moving_modules_with_from_imports(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        code = ('from pkg import mod4\n'
+                'print(mod4)')
+        self.mod1.write(code)
+        self._move(self.mod1, code.index('pkg') + 1, pkg2)
+        self.assertFalse(self.pkg.exists())
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod4') is not None)
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod5') is not None)
+        expected = ('from pkg2.pkg import mod4\n'
+                    'print(mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_modules_with_from_import(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        pkg3 = testutils.create_package(self.project, 'pkg3', pkg2)
+        pkg4 = testutils.create_package(self.project, 'pkg4', pkg3)
+        code = ('from pkg import mod4\n'
+                'print(mod4)')
+        self.mod1.write(code)
+        self._move(self.mod4, None, pkg4)
+        self.assertTrue(
+            self.project.find_module('pkg2.pkg3.pkg4.mod4') is not None)
+        expected = ('from pkg2.pkg3.pkg4 import mod4\n'
+                    'print(mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_modules_with_multi_from_imports(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        pkg3 = testutils.create_package(self.project, 'pkg3', pkg2)
+        pkg4 = testutils.create_package(self.project, 'pkg4', pkg3)
+        code = ('from pkg import mod4, mod5\n'
+                'print(mod4)')
+        self.mod1.write(code)
+        self._move(self.mod4, None, pkg4)
+        self.assertTrue(
+            self.project.find_module('pkg2.pkg3.pkg4.mod4') is not None)
+        expected = ('from pkg import mod5\n'
+                    'from pkg2.pkg3.pkg4 import mod4\n'
+                    'print(mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_modules_with_from_and_normal_imports(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        pkg3 = testutils.create_package(self.project, 'pkg3', pkg2)
+        pkg4 = testutils.create_package(self.project, 'pkg4', pkg3)
+        code = ('from pkg import mod4\n'
+                'import pkg.mod4\n'
+                'print(mod4)\n'
+                'print(pkg.mod4)')
+        self.mod1.write(code)
+        self._move(self.mod4, None, pkg4)
+        self.assertTrue(
+            self.project.find_module('pkg2.pkg3.pkg4.mod4') is not None)
+        expected = ('import pkg2.pkg3.pkg4.mod4\n'
+                    'from pkg2.pkg3.pkg4 import mod4\n'
+                    'print(mod4)\n'
+                    'print(pkg2.pkg3.pkg4.mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_modules_with_normal_and_from_imports(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        pkg3 = testutils.create_package(self.project, 'pkg3', pkg2)
+        pkg4 = testutils.create_package(self.project, 'pkg4', pkg3)
+        code = ('import pkg.mod4\n'
+                'from pkg import mod4\n'
+                'print(mod4)\n'
+                'print(pkg.mod4)')
+        self.mod1.write(code)
+        self._move(self.mod4, None, pkg4)
+        self.assertTrue(
+            self.project.find_module('pkg2.pkg3.pkg4.mod4') is not None)
+        expected = ('import pkg2.pkg3.pkg4.mod4\n'
+                    'from pkg2.pkg3.pkg4 import mod4\n'
+                    'print(mod4)\n'
+                    'print(pkg2.pkg3.pkg4.mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_modules_from_import_variable(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        pkg3 = testutils.create_package(self.project, 'pkg3', pkg2)
+        pkg4 = testutils.create_package(self.project, 'pkg4', pkg3)
+        code = ('from pkg.mod4 import foo\n'
+                'print(foo)')
+        self.mod1.write(code)
+        self._move(self.mod4, None, pkg4)
+        self.assertTrue(
+            self.project.find_module('pkg2.pkg3.pkg4.mod4') is not None)
+        expected = ('from pkg2.pkg3.pkg4.mod4 import foo\n'
+                    'print(foo)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_modules_normal_import(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        pkg3 = testutils.create_package(self.project, 'pkg3', pkg2)
+        pkg4 = testutils.create_package(self.project, 'pkg4', pkg3)
+        code = ('import pkg.mod4\n'
+                'print(pkg.mod4)')
+        self.mod1.write(code)
+        self._move(self.mod4, None, pkg4)
+        self.assertTrue(
+            self.project.find_module('pkg2.pkg3.pkg4.mod4') is not None)
+        expected = ('import pkg2.pkg3.pkg4.mod4\n'
+                    'print(pkg2.pkg3.pkg4.mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_package_with_from_and_normal_imports(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        code = ('from pkg import mod4\n'
+                'import pkg.mod4\n'
+                'print(pkg.mod4)\n'
+                'print(mod4)')
+        self.mod1.write(code)
+        self._move(self.mod1, code.index('pkg') + 1, pkg2)
+        self.assertFalse(self.pkg.exists())
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod4') is not None)
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod5') is not None)
+        expected = ('from pkg2.pkg import mod4\n'
+                    'import pkg2.pkg.mod4\n'
+                    'print(pkg2.pkg.mod4)\n'
+                    'print(mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_package_with_from_and_normal_imports2(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2')
+        code = ('import pkg.mod4\n'
+                'from pkg import mod4\n'
+                'print(pkg.mod4)\n'
+                'print(mod4)')
+        self.mod1.write(code)
+        self._move(self.mod1, code.index('pkg') + 1, pkg2)
+        self.assertFalse(self.pkg.exists())
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod4') is not None)
+        self.assertTrue(self.project.find_module('pkg2.pkg.mod5') is not None)
+        expected = ('import pkg2.pkg.mod4\n'
+                    'from pkg2.pkg import mod4\n'
+                    'print(pkg2.pkg.mod4)\n'
+                    'print(mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_package_and_retaining_blank_lines(self):
+        pkg2 = testutils.create_package(self.project, 'pkg2', self.pkg)
+        code = ('"""Docstring followed by blank lines."""\n\n'
+                'import pkg.mod4\n\n'
+                'from pkg import mod4\n'
+                'from x import y\n'
+                'from y import z\n'
+                'from a import b\n'
+                'from b import c\n'
+                'print(pkg.mod4)\n'
+                'print(mod4)')
+        self.mod1.write(code)
+        self._move(self.mod4, None, pkg2)
+        expected = ('"""Docstring followed by blank lines."""\n\n'
+                    'import pkg.pkg2.mod4\n\n'
+                    'from x import y\n'
+                    'from y import z\n'
+                    'from a import b\n'
+                    'from b import c\n'
+                    'from pkg.pkg2 import mod4\n'
+                    'print(pkg.pkg2.mod4)\n'
+                    'print(mod4)')
+        self.assertEquals(expected, self.mod1.read())
+
+    def test_moving_functions_to_imported_module(self):
         code = 'import mod1\n' \
                'def a_func():\n' \
                '    var = mod1.a_var\n'
