@@ -1,6 +1,11 @@
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
+import sys
 
 from rope.base import ast
+from rope.base.utils import pycompat
 from rope.refactor import patchedast
 from ropetest import testutils
 
@@ -25,11 +30,59 @@ class PatchedASTTest(unittest.TestCase):
         start = source.index('10')
         checker.check_region('Num', start, start + 2)
 
+    def test_negative_integer_literals_and_region(self):
+        source = 'a = -10\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        start = source.index('-10')
+        end = start + 3
+        # Python 3 parses as UnaryOp(op=USub(), operand=Num(n=10))
+        if pycompat.PY3:
+          start += 1
+        checker.check_region('Num', start, end)
+
+    def test_scientific_integer_literals_and_region(self):
+        source = 'a = -1.0e-3\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        start = source.index('-1.0e-3')
+        end = start + 7
+        # Python 3 parses as UnaryOp(op=USub(), operand=Num(n=10))
+        if pycompat.PY3:
+          start += 1
+        checker.check_region('Num', start, end)
+
+    def test_hex_integer_literals_and_region(self):
+        source = 'a = 0x1\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        start = source.index('0x1')
+        checker.check_region('Num', start, start + 3)
+
+    @testutils.only_for_versions_lower('3')
+    def test_long_literals_and_region(self):
+        source = 'a = 0x1L\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        start = source.index('0x1L')
+        checker.check_region('Num', start, start + 4)
+
+    def test_octal_integer_literals_and_region(self):
+        source = 'a = -0125e1\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        start = source.index('-0125e1')
+        end = start + 7
+        # Python 3 parses as UnaryOp(op=USub(), operand=Num(n=10))
+        if pycompat.PY3:
+          start += 1
+        checker.check_region('Num', start, end)
+
     def test_integer_literals_and_sorted_children(self):
         source = 'a = 10\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
-        #start = source.index('10')
+        # start = source.index('10')
         checker.check_children('Num', ['10'])
 
     def test_ass_name_node(self):
@@ -156,6 +209,7 @@ class PatchedASTTest(unittest.TestCase):
         checker = _ResultChecker(self, ast_frag)
         checker.check_children('Module', ['', 'Expr', '\n', 'Expr', '\n'])
 
+    @testutils.only_for_versions_lower('3')
     def test_long_integer_literals(self):
         source = "0x1L + a"
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -228,6 +282,7 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children(
             'AugAssign', ['Name', ' ', '+', '', '=', ' ', 'Num'])
 
+    @testutils.only_for_versions_lower('3')
     def test_back_quotenode(self):
         source = '`1`\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -268,6 +323,7 @@ class PatchedASTTest(unittest.TestCase):
             'Call', ['Name', '', '(', '', 'Num', '', ',',
                      ' ', 'keyword', '', ')'])
 
+    @testutils.only_for_versions_lower('3.5')
     def test_call_func_and_start_args(self):
         source = 'f(1, *args)\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -276,6 +332,16 @@ class PatchedASTTest(unittest.TestCase):
             'Call', ['Name', '', '(', '', 'Num', '', ',',
                      ' ', '*', '', 'Name', '', ')'])
 
+    @testutils.only_for('3.5')
+    def test_call_func_and_start_argspython35(self):
+        source = 'f(1, *args)\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        checker.check_children(
+            'Call', ['Name', '', '(', '', 'Num', '', ',',
+                ' *', 'Starred', '', ')'])
+ 
+    @testutils.only_for_versions_lower('3.5')
     def test_call_func_and_only_dstart_args(self):
         source = 'f(**kwds)\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -283,6 +349,15 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children(
             'Call', ['Name', '', '(', '', '**', '', 'Name', '', ')'])
 
+    @testutils.only_for('3.5')
+    def test_call_func_and_only_dstart_args_python35(self):
+        source = 'f(**kwds)\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        checker.check_children(
+            'Call', ['Name', '', '(', '**', 'keyword', '', ')'])
+
+    @testutils.only_for_versions_lower('3.5')
     def test_call_func_and_both_varargs_and_kwargs(self):
         source = 'f(*args, **kwds)\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -291,6 +366,15 @@ class PatchedASTTest(unittest.TestCase):
             'Call', ['Name', '', '(', '', '*', '', 'Name', '', ',',
                      ' ', '**', '', 'Name', '', ')'])
 
+    @testutils.only_for('3.5')
+    def test_call_func_and_both_varargs_and_kwargs_python35(self):
+        source = 'f(*args, **kwds)\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        checker.check_children(
+            'Call', ['Name', '', '(', '*', 'Starred', '', ',',
+                     ' **', 'keyword', '', ')'])
+
     def test_class_node(self):
         source = 'class A(object):\n    """class docs"""\n    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -371,10 +455,12 @@ class PatchedASTTest(unittest.TestCase):
             'Function', ['def', ' ', 'f', '', '(', '', 'arguments',
                          '', ')', '', ':', '\n    ', 'Expr', '\n    ',
                          'Pass'])
+        expected_child = pycompat.ast_arg_type.__name__
         checker.check_children(
-            'arguments', ['Name', '', ',',
+            'arguments', [expected_child, '', ',',
                           ' ', '**', '', 'p2'])
 
+    @testutils.only_for_versions_lower('3')
     def test_function_node_and_tuple_parameters(self):
         source = 'def f(a, (b, c)):\n    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -402,6 +488,7 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_region('BinOp', 0, len(source) - 1)
         checker.check_children('BinOp', ['Num', ' ', '/', ' ', 'Num'])
 
+    @testutils.only_for_versions_lower('3')
     def test_simple_exec_node(self):
         source = 'exec ""\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -409,6 +496,7 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_region('Exec', 0, len(source) - 1)
         checker.check_children('Exec', ['exec', ' ', 'Str'])
 
+    @testutils.only_for_versions_lower('3')
     def test_exec_node(self):
         source = 'exec "" in locals(), globals()\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -543,8 +631,10 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_region('Lambda', 0, len(source) - 1)
         checker.check_children(
             'Lambda', ['lambda', ' ', 'arguments', '', ':', ' ', 'Name'])
+        expected_child = pycompat.ast_arg_type.__name__
         checker.check_children(
-            'arguments', ['Name', '', ',', ' ', 'Name', '', '=', '',
+            'arguments', [expected_child, '', ',', ' ',
+                          expected_child, '', '=', '',
                           'Num', '', ',', ' ', '*', '', 'z'])
 
     def test_list_node(self):
@@ -578,6 +668,21 @@ class PatchedASTTest(unittest.TestCase):
             'comprehension', ['for', ' ', 'Name', ' ', 'in', ' ',
                               'Call', ' ', 'if', ' ', 'Name'])
 
+    def test_set_node(self):
+        # make sure we are in a python version with set literals
+        source = '{1, 2}\n'
+
+        try:
+            eval(source)
+        except SyntaxError:
+            return
+
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        checker.check_region('Set', 0, len(source) - 1)
+        checker.check_children(
+            'Set', ['{', '', 'Num', '', ',', ' ', 'Num', '', '}'])
+
     def test_set_comp_node(self):
         # make sure we are in a python version with set comprehensions
         source = '{i for i in range(1) if True}\n'
@@ -644,6 +749,7 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children('Expr', ['BoolOp'])
         checker.check_children('BoolOp', ['UnaryOp', ' ', 'or', ' ', 'Name'])
 
+    @testutils.only_for_versions_lower('3')
     def test_print_node(self):
         source = 'print >>out, 1,\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -652,6 +758,7 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children('Print', ['print', ' ', '>>', '', 'Name', '',
                                          ',', ' ', 'Num', '', ','])
 
+    @testutils.only_for_versions_lower('3')
     def test_printnl_node(self):
         source = 'print 1\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -659,7 +766,8 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_region('Print', 0, len(source) - 1)
         checker.check_children('Print', ['print', ' ', 'Num'])
 
-    def test_raise_node(self):
+    @testutils.only_for_versions_lower('3')
+    def test_raise_node_for_python2(self):
         source = 'raise x, y, z\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
@@ -668,6 +776,16 @@ class PatchedASTTest(unittest.TestCase):
             'Raise', ['raise', ' ', 'Name', '', ',', ' ', 'Name', '', ',',
                       ' ', 'Name'])
 
+    # @#testutils.only_for('3')
+    @unittest.skipIf(sys.version < '3', 'This is wrong')
+    def test_raise_node_for_python3(self):
+        source = 'raise x(y)\n'
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        checker.check_region('Raise', 0, len(source) - 1)
+        checker.check_children(
+            'Raise', ['raise', ' ', 'Call'])
+
     def test_return_node(self):
         source = 'def f():\n    return None\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -746,8 +864,9 @@ class PatchedASTTest(unittest.TestCase):
 
     @testutils.only_for('2.5')
     def test_with_node(self):
-        source = 'from __future__ import with_statement\nwith a as ' \
-            'b:\n    pass\n'
+        source = 'from __future__ import with_statement\n' +\
+                 'with a as b:\n' +\
+                 '    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
         checker.check_children(
@@ -758,10 +877,19 @@ class PatchedASTTest(unittest.TestCase):
         source = 'try:\n    pass\nfinally:\n    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
+        node_to_test = 'Try' if pycompat.PY3 else 'TryFinally'
+        if pycompat.PY3:
+            expected_children = ['try', '', ':', '\n    ',
+                                 'Pass', '\n', 'finally',
+                                 '', ':', '\n    ', 'Pass']
+        else:
+            expected_children = ['try', '', ':', '\n    ',
+                                 'Pass', '\n', 'finally', '', ':', '\n    ',
+                                 'Pass']
         checker.check_children(
-            'TryFinally', ['try', '', ':', '\n    ', 'Pass', '\n', 'finally',
-                           '', ':', '\n    ', 'Pass'])
+            node_to_test, expected_children)
 
+    @testutils.only_for_versions_lower('3')
     def test_try_except_node(self):
         source = 'try:\n    pass\nexcept Exception, e:\n    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -778,12 +906,14 @@ class PatchedASTTest(unittest.TestCase):
         source = 'try:\n    pass\nexcept Exception as e:\n    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
+        node_to_test = 'Try' if pycompat.PY3 else 'TryExcept'
         checker.check_children(
-            'TryExcept', ['try', '', ':', '\n    ', 'Pass', '\n',
-                          ('excepthandler', 'ExceptHandler')])
+            node_to_test, ['try', '', ':', '\n    ', 'Pass', '\n',
+                           ('excepthandler', 'ExceptHandler')])
+        expected_child = 'e' if pycompat.PY3 else 'Name'
         checker.check_children(
             ('excepthandler', 'ExceptHandler'),
-            ['except', ' ', 'Name', ' ', 'as', ' ', 'Name', '', ':',
+            ['except', ' ', 'Name', ' ', 'as', ' ', expected_child, '', ':',
              '\n    ', 'Pass'])
 
     @testutils.only_for('2.5')
@@ -791,9 +921,18 @@ class PatchedASTTest(unittest.TestCase):
         source = 'try:\n    pass\nexcept:\n    pass\nfinally:\n    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
         checker = _ResultChecker(self, ast_frag)
+        node_to_test = 'Try' if pycompat.PY3 else 'TryFinally'
+        if pycompat.PY3:
+            expected_children = ['try', '', ':', '\n    ', 'Pass', '\n',
+                                 'ExceptHandler', '\n',
+                                 'finally', '', ':', '\n    ', 'Pass']
+        else:
+            expected_children = ['TryExcept', '\n',
+                                 'finally', '', ':', '\n    ', 'Pass']
         checker.check_children(
-            'TryFinally', ['TryExcept', '\n', 'finally',
-                           '', ':', '\n    ', 'Pass'])
+            node_to_test,
+            expected_children
+        )
 
     def test_ignoring_comments(self):
         source = '#1\n1\n'
@@ -816,6 +955,7 @@ class PatchedASTTest(unittest.TestCase):
         checker.check_children(
             'Module', ['', 'Expr', '\n', 'Expr', '\n'])
 
+    @testutils.only_for_versions_lower('3')
     def test_how_to_handle_old_not_equals(self):
         source = '1 <> 2\n'
         ast_frag = patchedast.get_patched_ast(source, True)
