@@ -1,5 +1,8 @@
 import sys
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 import rope.base.codeanalyze
 import rope.refactor.occurrences
@@ -13,7 +16,6 @@ class RenameRefactoringTest(unittest.TestCase):
     def setUp(self):
         super(RenameRefactoringTest, self).setUp()
         self.project = testutils.sample_project()
-        self.pycore = self.project.pycore
 
     def tearDown(self):
         testutils.remove_project(self.project)
@@ -211,7 +213,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2.write('from mod1 import a_func\n')
         self._rename(mod2, mod2.read().index('mod1') + 1, 'newmod')
         self.assertTrue(not mod1.exists() and
-                        self.pycore.find_module('newmod') is not None)
+                        self.project.find_module('newmod') is not None)
         self.assertEquals('from newmod import a_func\n', mod2.read())
 
     def test_renaming_packages(self):
@@ -221,8 +223,8 @@ class RenameRefactoringTest(unittest.TestCase):
         mod2 = testutils.create_module(self.project, 'mod2', pkg)
         mod2.write('from pkg.mod1 import a_func\n')
         self._rename(mod2, 6, 'newpkg')
-        self.assertTrue(self.pycore.find_module('newpkg.mod1') is not None)
-        new_mod2 = self.pycore.find_module('newpkg.mod2')
+        self.assertTrue(self.project.find_module('newpkg.mod1') is not None)
+        new_mod2 = self.project.find_module('newpkg.mod2')
         self.assertEquals('from newpkg.mod1 import a_func\n', new_mod2.read())
 
     def test_module_dependencies(self):
@@ -230,7 +232,7 @@ class RenameRefactoringTest(unittest.TestCase):
         mod1.write('class AClass(object):\n    pass\n')
         mod2 = testutils.create_module(self.project, 'mod2')
         mod2.write('import mod1\na_var = mod1.AClass()\n')
-        self.pycore.resource_to_pyobject(mod2).get_attributes()['mod1']
+        self.project.get_pymodule(mod2).get_attributes()['mod1']
         mod1.write('def AClass():\n    return 0\n')
 
         self._rename(mod2, len(mod2.read()) - 3, 'a_func')
@@ -326,10 +328,10 @@ class RenameRefactoringTest(unittest.TestCase):
     def test_rename_in_module_renaming_one_letter_names_for_expressions(self):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write('a = 10\nprint(1+a)\n')
-        pymod = self.pycore.get_module('mod1')
+        pymod = self.project.get_module('mod1')
         old_pyname = pymod['a']
         finder = rope.refactor.occurrences.create_finder(
-            self.pycore, 'a', old_pyname)
+            self.project, 'a', old_pyname)
         refactored = rename.rename_in_module(
             finder, 'new_var', pymodule=pymod, replace_primary=True)
         self.assertEquals('new_var = 10\nprint(1+new_var)\n', refactored)
